@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION     = '0.099';
+our $VERSION     = '0.100';
 $VERSION = eval $VERSION;
 
 1;
@@ -14,11 +14,11 @@ __END__
 
 =head1 NAME
 
-Gtk2::Ex::DbLinker - Use sql or orm objects to build a gtk2 Gui
+Gtk2::Ex::DbLinker - Gui building part with Gtk2 of DbLinker
 
 =head1 VERSION
 
-version  0.099 but see version at the end of MYMETA.yml to check that I'm correct here...
+version  0.100 but see version at the end of MYMETA.yml to check that I'm correct here...
 
 =head1 INSTALLATION
 
@@ -34,14 +34,11 @@ On windows use nmake or dmake instead of make.
 
 The following modules are required in order to use Gtk2::Ex::Linker
 
-	Test::Simple => 0.44,
-	GLib => 1.240,
+	Gtk2::Ex::DbLinker::DbTools => 0.99
+	DateTime::Format::Strptime => 1.5,
+	Test::More => 0.44,
 	Gtk2 => 1.240,
-	Class::Interface => 1.01,
-	DateTime::Format::Strptime => 1.5
 	Carp => 1.17
-	Gtk2::Ex::Dialogs => 0.11
-	DBI => 1.631
 	Log::Log4perl => 1.41
 
 Install one of Rose::DB::Object or DBIx::Class if you want to use these orm to access your data.
@@ -144,6 +141,10 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
+=head1 SEE ALSO
+
+L<Gtk2::Ex::DbLinker::DbTools>
+
 =cut
 
 
