@@ -101,6 +101,8 @@ sub new {
 		push @dates, $v;
 	}
 	 $self->{dates_formatted} = \@dates;
+         my %hdates = map {$_ => 1} @dates;
+         $self->{hdates_formatted} = \%hdates;
  	$self->{dates_formatters} = {};
 
  	$self->{pos2del} = [];
@@ -326,7 +328,8 @@ sub _display_data {
 	
 		# $w->signal_handler_block()
 
-		if ( $id ~~ @{$self->{dates_formatted}}){
+		#if ( $id ~~ @{$self->{dates_formatted}}){
+		if ( defined $self->{hdates_formatted}->{$id}) {
 			#$x = $self->_dateformatter($self->{date_formatters}->{$id}, $x);
 			if ( defined $x){
 				#my $ff = $self->{dates_formatters_f}->{$id};
@@ -451,13 +454,15 @@ sub apply{
 
 			@pk = $self->{dman}->get_autoinc_primarykeys;
 
-			if ($id ~~ @pk)  {
+			#if ($id ~~ @pk)  {
+			if (grep /^$id$/, @pk) {
 				$self->{log}->debug("not done because it's a auto incremented pk");
 			} else {
 		
 				$v = ($v eq "" ? undef : $v);
 				$self->{log}->debug($id  . ": value undef") unless ( defined $v);	
-				if ( defined $v && ( $id ~~ @{$self->{dates_formatted}})){
+				# if ( defined $v && ( $id ~~ @{$self->{dates_formatted}})){
+				if ( defined $v && defined $self->{hdates_formatted}->{$id}){
 					#my $ff = $self->{dates_formatters_f}->{$id};
 				
 					#my $date = $ff->parse_datetime($v);
